# eric7.Plugins.VcsPlugins.vcsMercurial.LargefilesExtension.ProjectBrowserHelper

Module implementing the largefiles extension project browser helper.

### Global Attributes

None

### Classes

LargefilesProjectBrowserHelper | Class implementing the largefiles extension project browser helper.

### Functions

None

## LargefilesProjectBrowserHelper

Class implementing the largefiles extension project browser helper.

### Derived from

HgExtensionProjectBrowserHelper

### Class Attributes

None

### Class Methods

None

### Methods

LargefilesProjectBrowserHelper | Constructor
__hgAddLargefiles | Private slot to add the selected files as large files.
initMenus | Public method to generate the extension menus.
menuTitle | Public method to get the menu title.
showExtensionMenu | Public method to prepare the extension menu for display.

### Static Methods

None

#### LargefilesProjectBrowserHelper (Constructor)

LargefilesProjectBrowserHelper(vcsObject, browserObject, projectObject)

Constructor

vcsObject (Hg)
  reference to the vcs object
browserObject (ProjectBaseBrowser)
  reference to the project browser object
projectObject (Project)
  reference to the project object

#### LargefilesProjectBrowserHelper.__hgAddLargefiles

__hgAddLargefiles(mode)

Private slot to add the selected files as large files.

mode (str)
  add mode (string ne of 'normal' or 'large')

#### LargefilesProjectBrowserHelper.initMenus

initMenus()

Public method to generate the extension menus.

Note: Derived class must implement this method.

Return:
  dictionary of populated menu. The dict must have the keys 'mainMenu', 'multiMenu', 'backMenu', 'dirMenu' and 'dirMultiMenu'.

Return Type:
  dict of QMenu

#### LargefilesProjectBrowserHelper.menuTitle

menuTitle()

Public method to get the menu title.

Note: Derived class must implement this method.

Return:
  title of the menu

Return Type:
  str

#### LargefilesProjectBrowserHelper.showExtensionMenu

showExtensionMenu(key, controlled)

Public method to prepare the extension menu for display.

key (str)
  menu key (one of 'mainMenu', 'multiMenu', 'backMenu', 'dirMenu' or 'dirMultiMenu')
controlled (bool)
  flag indicating to prepare the menu for a version controlled entry or a non-version controlled entry

Up